@@ -1,5 +1,5 @@
 kcv.plr <-
-  function(x, y, foldid = NULL, alpha, nfolds = NULL,
+  function(x, y, foldid = NULL, alpha, nfolds = NULL, 
            family = c("binomial", "multinomial"), offset = NULL, lambda = NULL, 
            weights = NULL, standardize = FALSE, grouped = TRUE, keep = FALSE, 
            parallel = FALSE, maxit = 1e+06) 
@@ -7,29 +7,55 @@ kcv.plr <-
     if (!is.factor(y)) {
       y <- factor(y)
     } 
+    if (length(unique(y)) == 1L)
+      stop("Input 'y' must contain some variation (i.e., cannot contain \n
+           only a single type of label).")
     if (is.null(nfolds)) {
       nfolds <- 10
     } else {
+      if (!(is.integer(nfolds) || is.numeric(nfolds))) {
+        stop("Input 'nfolds' must be of class 'integer' or 'numeric'.")
+      }
+      if (length(unique(nfolds)) != 1L) {
+        stop("Input 'nfolds' must contain only a single value.")
+      }
       if ((nfolds %% 1) != 0) {
         stop("Input 'nfolds' must be an integer.")
       }
       if ((nfolds < 2) | (nfolds > length(y))) {
-        stop("Input 'nfolds must be an integer between 2 and the \n
-             number of observations, inclusive.")
+        stop("Input 'nfolds' must be an integer between 2 and the \n
+             number of observations, inclusive. Alternatively, the \n
+             number of observations cannot be less than 'nfolds'.")
       }
     }
+    if (is.null(parallel)) {
+      parallel <- FALSE
+    } else {
+      if (!(is.logical(parallel))) {
+        stop("Input 'parallel' must be of class 'logical'.")
+      }
+      if (length(unique(parallel)) != 1L) {
+        stop("Input 'parallel' must contain only a single value.")
+      }  
+    }
     if (is.null(foldid)) {
       foldid <- sample(rep(1:nfolds, length.out = length(y)))
     }
+    if (length(unique(foldid)) != as.integer(nfolds)) {
+      stop("Input 'foldid' must contain the number of unique values equal to \n
+           input 'nfolds'.")
+    }
     lalpha <- length(alpha)
-    yweight <- cbind(y, weights)
     cvlist <- vector("list", lalpha)
     if (ncol(x) == 1) {
       x <- cbind(0, x)
     }
     if (nfolds == 2) {
-      if (family == "binomial") {
-        threshold <- yweight[which(yweight[,1] == 2), 2]
+      if (is.null(weights)) {
+        weights <- as.numeric((table(y)[y] / length(y)))
+        if (family == "binomial") {
+          threshold <- (table(y) / length(y))[1]
+        }
       }
       stor.cvm <- rep(NA, lalpha)
       stor.minlam <- rep(NA, lalpha)
@@ -91,7 +117,7 @@ kcv.plr <-
       }
       mincv <- sapply(cvlist, function(x) min(x$cvm))
       minid <- which.min(mincv)
-    }
+    } 
     if (nfolds == 2) {
       return(list(alpha.id = minid, plr.fit = fit0,
                   error = mincv[minid], lambda.min = minlam))
