@@ -8,12 +8,44 @@ kcv.svm <-
     if (!is.factor(y)) {
       y <- factor(y)
     }
+    if (length(unique(y)) == 1L)
+      stop("Input 'y' must contain some variation (i.e., cannot contain \n
+           only a single type of label).")
     if (is.null(nfolds)) {
       nfolds <- 10
+    } else {
+      if (!(is.integer(nfolds) || is.numeric(nfolds))) {
+        stop("Input 'nfolds' must be of class 'integer' or 'numeric'.")
+      }
+      if (length(unique(nfolds)) != 1L) {
+        stop("Input 'nfolds' must contain only a single value.")
+      }
+      if ((nfolds %% 1) != 0) {
+        stop("Input 'nfolds' must be an integer.")
+      }
+      if ((nfolds < 2) | (nfolds > length(y))) {
+        stop("Input 'nfolds' must be an integer between 2 and the \n
+             number of observations, inclusive. Alternatively, the \n
+             number of observations cannot be less than 'nfolds'.")
+      }
+    }
+    if (is.null(parallel)) {
+      parallel <- FALSE
+    } else {
+      if (!(is.logical(parallel))) {
+        stop("Input 'parallel' must be of class 'logical'.")
+      }
+      if (length(unique(parallel)) != 1L) {
+        stop("Input 'parallel' must contain only a single value.")
+      }  
     }
     if (is.null(foldid)) {
       foldid <- sample(rep(1:nfolds, length.out = length(y)))
     }
+    if (length(unique(foldid)) != as.integer(nfolds)) {
+      stop("Input 'foldid' must contain the number of unique values equal to \n
+           input 'nfolds'.")
+    }
     grid.row <- nrow(svm.grid)
     cv.svm <- matrix(rep(0, grid.row * nfolds), ncol = nfolds)
     if (parallel == TRUE) {
